@@ -1,4 +1,6 @@
-from pkg_resources import parse_version
+import os
+import shutil
+import tempfile
 
 import numpy as np
 import pytest
@@ -95,9 +97,7 @@ def test_equivalent_proj():
 def test_equivalent_proj__disabled():
     transformer = Transformer.from_proj(3857, pyproj.Proj(3857).crs.to_proj4())
     assert not transformer._transformer.skip_equivalent
-    assert transformer._transformer.projections_equivalent == (
-        parse_version(pyproj.proj_version_str) >= parse_version("6.2.0")
-    )
+    assert transformer._transformer.projections_equivalent
     assert not transformer._transformer.projections_exact_same
 
 
@@ -442,6 +442,65 @@ def test_repr():
     )
 
 
+def test_to_json_dict():
+    transformer = Transformer.from_crs(4326, 3857)
+    json_dict = transformer.to_json_dict()
+    assert json_dict["type"] == "Conversion"
+
+
+def test_to_json():
+    transformer = Transformer.from_crs(4326, 3857)
+    json_data = transformer.to_json()
+    assert "Conversion" in json_data
+    assert "\n" not in json_data
+
+
+def test_to_json__pretty():
+    transformer = Transformer.from_crs(4326, 3857)
+    json_data = transformer.to_json(pretty=True)
+    assert "Conversion" in json_data
+    assert json_data.startswith('{\n  "')
+
+
+def test_to_json__pretty__indenation():
+    transformer = Transformer.from_crs(4326, 3857)
+    json_data = transformer.to_json(pretty=True, indentation=4)
+    assert "Conversion" in json_data
+    assert json_data.startswith('{\n    "')
+
+
+def test_transformer__operations():
+    transformer = Transformer.from_crs(28356, 7856)
+    assert [op.name for op in transformer.operations] == [
+        "Inverse of Map Grid of Australia zone 56",
+        "GDA94 to GDA2020 (1)",
+        "Map Grid of Australia zone 56",
+    ]
+
+
+def test_transformer__operations_missing():
+    assert Transformer.from_crs(7789, 8401).operations == ()
+
+
+def test_transformer__operations__scope_remarks():
+    transformer = Transformer.from_crs(28356, 7856)
+    assert transformer.scope is None
+    assert [op.scope for op in transformer.operations] == [
+        None,
+        "Conformal transformation of GDA94 coordinates that have been derived through "
+        "GNSS CORS.",
+        None,
+    ]
+    assert [op.remarks for op in transformer.operations] == [
+        None,
+        "Scale difference in ppb where 1/billion = 1E-9. Derivation excluded Cocos, "
+        "Christmas and Macquarie Islands but is applied there. See codes 8444-46 for "
+        "equivalents using NTv2 method. See code 8447 for alternative including "
+        "distortion model for Aus only.",
+        None,
+    ]
+
+
 def test_transformer_group():
     trans_group = TransformerGroup(7789, 8401)
     assert len(trans_group.transformers) == 2
@@ -479,7 +538,28 @@ def test_transform_group__missing_best():
     assert len(trans_group.unavailable_operations) == 41
 
 
-def test_transform_group__area_of_interest():
+@pytest.fixture(scope="module")
+def aoi_data_directory():
+    """
+    This is to ensure that the ntv2_0.gsb file is actually
+    missing for the AOI tests.
+    """
+    data_dir = pyproj.datadir.get_data_dir()
+    with tempfile.TemporaryDirectory() as tmpdir:
+        tmp_data_dir = os.path.join(tmpdir, "proj")
+        shutil.copytree(data_dir, tmp_data_dir)
+        try:
+            os.remove(os.path.join(str(tmp_data_dir), "ntv2_0.gsb"))
+        except OSError:
+            pass
+        try:
+            pyproj.datadir.set_data_dir(str(tmp_data_dir))
+            yield
+        finally:
+            pyproj.datadir.set_data_dir(data_dir)
+
+
+def test_transform_group__area_of_interest(aoi_data_directory):
     with pytest.warns(
         UserWarning, match="Best transformation is not available due to missing Grid"
     ):
@@ -492,27 +572,32 @@ def test_transform_group__area_of_interest():
     )
 
 
-def test_transformer__area_of_interest():
+def test_transformer_group__get_transform_crs():
+    tg = TransformerGroup("epsg:4258", "epsg:7415")
+    assert len(tg.transformers) == 4
+
+
+def test_transformer__area_of_interest(aoi_data_directory):
     transformer = Transformer.from_crs(
         4326, 2964, area_of_interest=AreaOfInterest(-136.46, 49.0, -60.72, 83.17)
     )
     assert transformer.description == "Inverse of NAD27 to WGS 84 (13) + Alaska Albers"
 
 
-def test_transformer_proj__area_of_interest():
+def test_transformer_proj__area_of_interest(aoi_data_directory):
     transformer = Transformer.from_proj(
         4326, 2964, area_of_interest=AreaOfInterest(-136.46, 49.0, -60.72, 83.17)
     )
     assert transformer.description == "Inverse of NAD27 to WGS 84 (13) + Alaska Albers"
 
 
-def test_transformer__area_of_interest__invalid():
+def test_transformer__area_of_interest__invalid(aoi_data_directory):
     with pytest.raises(ProjError):
         Transformer.from_crs(
             4326, 2964, area_of_interest=(-136.46, 49.0, -60.72, 83.17)
         )
 
 
-def test_transformer_group__area_of_interest__invalid():
+def test_transformer_group__area_of_interest__invalid(aoi_data_directory):
     with pytest.raises(ProjError):
         TransformerGroup(4326, 2964, area_of_interest=(-136.46, 49.0, -60.72, 83.17))
